<?php

namespace Drupal\layout_builder_base_library\Plugin\Layout;

use Drupal\layout_builder_base\Plugin\Layout\DefaultLayoutBase;

/**
 * Configurable layout plugin class.
 *
 * @internal
 *   Plugin classes are internal.
 */
class BaseOneColumnLayout extends DefaultLayoutBase {

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundOptions() {
    return [
      'layout--background--none' => $this->t('None'),
      'layout--background--white' => $this->t('White'),
      'layout--background--grey' => $this->t('Grey'),
      'layout--background--black' => $this->t('Black'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundAttachmentOptions() {
    return [
      'layout--background-attachment--default' => $this->t('Default'),
      'layout--background-attachment--fixed' => $this->t('Fixed'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundPositionOptions() {
    return [
      'layout--background-position--default' => $this->t('Default'),
      'layout--background-position--center' => $this->t('Center'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundSizeOptions() {
    return [
      'layout--background-size--default' => $this->t('Default'),
      'layout--background-size--cover' => $this->t('Cover'),
      'layout--background-size--contain' => $this->t('Contain'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundOverlayOptions() {
    return [
      'layout--background-overlay--none' => $this->t('None'),
      'layout--background-overlay--dark-light' => $this->t('Light Dark'),
      'layout--background-overlay--dark' => $this->t('Dark'),
      'layout--background-overlay--darker' => $this->t('Darker'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getTopMarginOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--top-margin--none' => $this->t('None'),
      'layout--top-margin--small' => $this->t('Small margin'),
      'layout--top-margin--default' => $this->t('Default margin'),
      'layout--top-margin--big' => $this->t('Big margin'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBottomMarginOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--bottom-margin--none' => $this->t('None'),
      'layout--bottom-margin--small' => $this->t('Small margin'),
      'layout--bottom-margin--default' => $this->t('Default margin'),
      'layout--bottom-margin--big' => $this->t('Big margin'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getLeftMarginOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--left-margin--none' => $this->t('None'),
      'layout--left-margin--small' => $this->t('Small margin'),
      'layout--left-margin--default' => $this->t('Default margin'),
      'layout--left-margin--big' => $this->t('Big margin'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getRightMarginOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--right-margin--none' => $this->t('None'),
      'layout--right-margin--small' => $this->t('Small margin'),
      'layout--right-margin--default' => $this->t('Default margin'),
      'layout--right-margin--big' => $this->t('Big margin'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualTopBottomMarginsOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--top-bottom-margin--none' => $this->t('None'),
      'layout--top-bottom-margin--small' => $this->t('Small margins'),
      'layout--top-bottom-margin--default' => $this->t('Default margins'),
      'layout--top-bottom-margin--big' => $this->t('Big margins'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualLeftRightMarginsOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--left-right-margin--none' => $this->t('None'),
      'layout--left-right-margin--small' => $this->t('Small margins'),
      'layout--left-right-margin--default' => $this->t('Default margins'),
      'layout--left-right-margin--big' => $this->t('Big margins'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getTopPaddingOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--top-padding--none' => $this->t('None'),
      'layout--top-padding--small' => $this->t('Small padding'),
      'layout--top-padding--default' => $this->t('Default padding'),
      'layout--top-padding--big' => $this->t('Big padding'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBottomPaddingOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--bottom-padding--none' => $this->t('None'),
      'layout--bottom-padding--small' => $this->t('Small padding'),
      'layout--bottom-padding--default' => $this->t('Default padding'),
      'layout--bottom-padding--big' => $this->t('Big padding'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getLeftPaddingOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--left-padding--none' => $this->t('None'),
      'layout--left-padding--small' => $this->t('Small padding'),
      'layout--left-padding--default' => $this->t('Default padding'),
      'layout--left-padding--big' => $this->t('Big padding'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getRightPaddingOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--right-padding--none' => $this->t('None'),
      'layout--right-padding--small' => $this->t('Small padding'),
      'layout--right-padding--default' => $this->t('Default padding'),
      'layout--right-padding--big' => $this->t('Big padding'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualTopBottomPaddingsOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--top-bottom-padding--none' => $this->t('None'),
      'layout--top-bottom-padding--small' => $this->t('Small paddings'),
      'layout--top-bottom-padding--default' => $this->t('Default paddings'),
      'layout--top-bottom-padding--big' => $this->t('Big paddings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualLeftRightPaddingsOptions() {
    return [
      '' => $this->t('Choose'),
      'layout--left-right-padding--none' => $this->t('None'),
      'layout--left-right-padding--small' => $this->t('Small paddings'),
      'layout--left-right-padding--default' => $this->t('Default paddings'),
      'layout--left-right-padding--big' => $this->t('Big paddings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getContainerOptions() {
    return [
      'layout--container--default' => $this->t('Default'),
      'layout--container--none' => $this->t('None'),
      'layout--container--small' => $this->t('Small'),
      'layout--container--large' => $this->t('Large'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getContentContainerOptions() {
    return [
      'layout--content-container--none' => $this->t('None'),
      'layout--content-container--small' => $this->t('Small'),
      'layout--content-container--default' => $this->t('Default'),
      'layout--content-container--large' => $this->t('Large'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getHeightOptions() {
    return [
      'layout--height--default' => $this->t('Default'),
      'layout--height--100vh' => $this->t('100vh'),
      'layout--height--80vh' => $this->t('80vh'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getColorsOptions() {
    return [
      'layout--color--default' => $this->t('Default'),
      'layout--color--black' => $this->t('Black'),
      'layout--color--white' => $this->t('White'),
      'layout--color--grey' => $this->t('Grey'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getAlignmentOptions() {
    return [
      '' => $this->t('Default'),
      'layout--alignment--left' => $this->t('Left'),
      'layout--alignment--right' => $this->t('Right'),
      'layout--alignment--center' => $this->t('Center'),
      'layout--alignment--justify' => $this->t('Justify'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function enableImageBackground() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultBackgroundPosition() {
    return 'layout--background-position--center';
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultBackgroundSize() {
    return 'layout--background-size--cover';
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);
    $build['#attached']['library'][] = 'layout_builder_base_library/layout-builder-base-library';
    return $build;
  }

}
